@@ -1,21 +1,11 @@
 from __future__ import annotations
 
 from functools import wraps
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Iterable,
-    Literal,
-    Mapping,
-    Sequence,
-    cast,
-    overload,
-)
+from typing import TYPE_CHECKING, Any, Callable, Literal, cast, overload
 from warnings import warn
 
 import narwhals as nw
-from narwhals import dependencies, exceptions, functions as nw_f, selectors
+from narwhals import exceptions, functions as nw_f
 from narwhals._typing_compat import TypeVar
 from narwhals._utils import (
     Implementation,
@@ -36,10 +26,10 @@ from narwhals.dataframe import DataFrame as NwDataFrame, LazyFrame as NwLazyFram
 from narwhals.dependencies import get_polars
 from narwhals.exceptions import InvalidIntoExprError
 from narwhals.expr import Expr as NwExpr
-from narwhals.functions import _new_series_impl, concat, get_level, show_versions
+from narwhals.functions import _new_series_impl, concat, show_versions
 from narwhals.schema import Schema as NwSchema
 from narwhals.series import Series as NwSeries
-from narwhals.stable.v1 import dtypes
+from narwhals.stable.v1 import dependencies, dtypes, selectors
 from narwhals.stable.v1.dtypes import (
     Array,
     Binary,
@@ -74,6 +64,7 @@ from narwhals.translate import _from_native_impl, get_native_namespace, to_py_sc
 from narwhals.typing import IntoDataFrameT, IntoFrameT
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable, Mapping, Sequence
     from types import ModuleType
 
     from typing_extensions import ParamSpec, Self
@@ -1327,6 +1318,10 @@ def sum_horizontal(*exprs: IntoExpr | Iterable[IntoExpr]) -> Expr:
 def all_horizontal(*exprs: IntoExpr | Iterable[IntoExpr]) -> Expr:
     r"""Compute the bitwise AND horizontally across columns.
 
+    [Kleene Logic](https://en.wikipedia.org/wiki/Three-valued_logic)
+    is followed, except for pandas' classical NumPy types which can't hold null
+    values, see [Boolean columns](../concepts/boolean.md).
+
     Arguments:
         exprs: Name(s) of the columns to use in the aggregation function. Accepts
             expression input.
@@ -1340,6 +1335,10 @@ def all_horizontal(*exprs: IntoExpr | Iterable[IntoExpr]) -> Expr:
 def any_horizontal(*exprs: IntoExpr | Iterable[IntoExpr]) -> Expr:
     r"""Compute the bitwise OR horizontally across columns.
 
+    [Kleene Logic](https://en.wikipedia.org/wiki/Three-valued_logic)
+    is followed, except for pandas' classical NumPy types which can't hold null
+    values, see [Boolean columns](../concepts/boolean.md).
+
     Arguments:
         exprs: Name(s) of the columns to use in the aggregation function. Accepts
             expression input.
@@ -1422,6 +1421,25 @@ def concat_str(
     )
 
 
+def get_level(
+    obj: DataFrame[Any] | LazyFrame[Any] | Series[IntoSeriesT],
+) -> Literal["full", "lazy", "interchange"]:
+    """Level of support Narwhals has for current object.
+
+    Arguments:
+        obj: Dataframe or Series.
+
+    Returns:
+        This can be one of
+
+            - 'full': full Narwhals API support
+            - 'lazy': only lazy operations are supported. This excludes anything
+              which involves iterating over rows in Python.
+            - 'interchange': only metadata operations are supported (`df.schema`)
+    """
+    return obj._level
+
+
 class When(nw_f.When):
     @classmethod
     def from_when(cls, when: nw_f.When) -> When:
