@@ -5,8 +5,8 @@ from typing import TYPE_CHECKING, Any
 import pytest
 
 import narwhals as nw
+from narwhals._utils import Implementation
 from narwhals.dependencies import get_cudf, get_modin
-from narwhals.utils import Implementation
 
 if TYPE_CHECKING:
     from tests.utils import ConstructorEager
