@@ -1,12 +1,15 @@
 from __future__ import annotations
 
 from dataclasses import asdict, dataclass
-from typing import Sequence
+from typing import TYPE_CHECKING
 
 import pytest
 
 import narwhals as nw
 
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
 
 # https://github.com/narwhals-dev/narwhals/issues/1486
 @dataclass
